var indexSectionsWithContent =
{
  0: "_abcdefghiklmnoprstuvw",
  1: "acdfgikmprsu",
  2: "i",
  3: "_acdefghiklprstuv",
  4: "abcdefghiklmnoprstuv",
  5: "acdfklw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Pages"
};

